@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: mozilla-helpers.cpp,v 1.1.2.6 2004/09/26 16:22:39 chpe Exp $
+ *  $Id: mozilla-helpers.cpp,v 1.1.2.7 2004/11/15 15:08:51 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -31,7 +31,9 @@
 #include <gtkmozembed.h>
 #include <gtkmozembed_internal.h>
 
+#define MOZILLA_STRICT_API
 #include <nsEmbedString.h>
+#undef MOZILLA_STRICT_API
 #include <nsCOMPtr.h>
 #include <nsICacheEntryDescriptor.h>
 #include <nsICacheService.h>
